# Luxsci.AuthenticationApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**authentication**](AuthenticationApi.md#authentication) | **POST** /auth | 
[**revokeAuthentication**](AuthenticationApi.md#revokeAuthentication) | **DELETE** /auth | 

<a name="authentication"></a>
# **authentication**
> InlineResponse201 authentication(opts)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication \&quot;session\&quot; can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a \&quot;log out\&quot;).   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.AuthenticationApi

let opts = { 
  'body': new Luxsci.AuthBody() // AuthBody | 
};
apiInstance.authentication(opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**AuthBody**](AuthBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

# **authentication**
> InlineResponse201 authentication(secret, token, user, pass)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication &quot;session&quot; can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a &quot;log out&quot;).   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```javascript
import {Luxsci} from 'luxsci';

let apiInstance = new Luxsci.AuthenticationApi();
apiInstance.authentication("SECRET","TOKEN").then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **secret** | **String**| |
 **token** | **String**| |
 **user** | **String**| | [optional]
 **cookie** | **String**| | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="revokeAuthentication"></a>
# **revokeAuthentication**
> InlineResponse200 revokeAuthentication()



Revoke your authentication session and invalidate all authorization codes received. See also [Revocation](/rest-api/mechanics.html#revoke).

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.AuthenticationApi


apiInstance.revokeAuthentication().then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

