# Luxsci.DomainsApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createDomain**](DomainsApi.md#createDomain) | **POST** /account/{accountId}/domains | 
[**deleteDomain**](DomainsApi.md#deleteDomain) | **DELETE** /account/{accountId}/domains/{domainName} | 
[**getDomainDetails**](DomainsApi.md#getDomainDetails) | **GET** /account/{accountId}/domains/{domainName} | 
[**getDomainsReport**](DomainsApi.md#getDomainsReport) | **GET** /account/{accountId}/domains | 
[**updateDomain**](DomainsApi.md#updateDomain) | **PUT** /account/{accountId}/domains/{domainName} | 

<a name="createDomain"></a>
# **createDomain**
> InlineResponse20059 createDomain(accountId, opts)



Create a new domain in your account. Note: the domain MUST be either a subdomain or have client-managed DNS.  For HIPAA accounts, all new domains will be locked down for HIPAA compliance unless the account is configured as “HIPAA Flexible.” In that case, all new domains cannot be created via the API.  Your API Interface looks to see how many domains were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional domain creation requests until that situation changes. See your API Interface configuration page for your domain creation limit. {{ACL: Account: Domains - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.DomainsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'body': new Luxsci.AccountIdDomainsBody(), // AccountIdDomainsBody | 
};
apiInstance.createDomain(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **body** | [**AccountIdDomainsBody**](AccountIdDomainsBody.md)|  | [optional] 

### Return type

[**InlineResponse20059**](InlineResponse20059.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteDomain"></a>
# **deleteDomain**
> InlineResponse2003 deleteDomain(accountId, domainName, opts)



Remove a domain from your account. If the domain is currently in use (e.g. has users, web sites, has premium filtering or archival, has managed DNS, etc.), then it cannot be deleted. Note: the domain MUST be either a subdomain or have client-managed DNS. {{ACL: Account: Domains - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.DomainsApi

let accountId = "accountId_example"; // String | 
let domainName = "domainName_example"; // String | 
let opts = { 
};
apiInstance.deleteDomain(accountId, domainName, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **domainName** | **String**|  | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDomainDetails"></a>
# **getDomainDetails**
> InlineResponse20060 getDomainDetails(accountId, domainName, opts)



Get information about a specific domain. This is the same as the “Get Domain Report,” except that it returns data for 1 specific domain. {{ACL: Account: Domains - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.DomainsApi

let accountId = "accountId_example"; // String | 
let domainName = "domainName_example"; // String | 
let opts = { 
};
apiInstance.getDomainDetails(accountId, domainName, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **domainName** | **String**|  | 

### Return type

[**InlineResponse20060**](InlineResponse20060.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDomainsReport"></a>
# **getDomainsReport**
> InlineResponse20058 getDomainsReport(accountId, opts)



Get information about your domains. {{ACL: Account: Domains - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.DomainsApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getDomainsReport(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20058**](InlineResponse20058.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateDomain"></a>
# **updateDomain**
> InlineResponse201 updateDomain(accountId, domainName, opts)



Change selected domain settings.  You can change one or multiple settings via one call. Settings that are omitted will not be altered. {{ACL: Account: Domains - Manage}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.DomainsApi

let accountId = "accountId_example"; // String | 
let domainName = "domainName_example"; // String | 
let opts = { 
  'body': new Luxsci.DomainsDomainNameBody(), // DomainsDomainNameBody | 
};
apiInstance.updateDomain(accountId, domainName, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **domainName** | **String**|  | 
 **body** | [**DomainsDomainNameBody**](DomainsDomainNameBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

