# Luxsci.SecureFormApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**deleteSecureFormDatabaseFile**](SecureFormApi.md#deleteSecureFormDatabaseFile) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
[**deleteSecureFormDatabaseRow**](SecureFormApi.md#deleteSecureFormDatabaseRow) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
[**getSecureForm**](SecureFormApi.md#getSecureForm) | **GET** /account/{accountId}/secureforms/{formID} | 
[**getSecureFormDatabaseFile**](SecureFormApi.md#getSecureFormDatabaseFile) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} | 
[**getSecureFormDatabasePosts**](SecureFormApi.md#getSecureFormDatabasePosts) | **GET** /account/{accountId}/secureforms/{formID}/db | 
[**getSecureFormDatabaseRow**](SecureFormApi.md#getSecureFormDatabaseRow) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} | 
[**getSecureFormDatabaseRows**](SecureFormApi.md#getSecureFormDatabaseRows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows | 
[**getSecureFormList**](SecureFormApi.md#getSecureFormList) | **GET** /account/{accountId}/secureforms | 

<a name="deleteSecureFormDatabaseFile"></a>
# **deleteSecureFormDatabaseFile**
> InlineResponse201 deleteSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex, opts)



This function is used to remove a file associated with a row in your SecureForm database. {{ACL: Account: SecureForm Database - Delete}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let rowIndex = "rowIndex_example"; // String | 
let fileIndex = "fileIndex_example"; // String | 
let opts = { 
};
apiInstance.deleteSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **rowIndex** | **String**|  | 
 **fileIndex** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteSecureFormDatabaseRow"></a>
# **deleteSecureFormDatabaseRow**
> InlineResponse201 deleteSecureFormDatabaseRow(accountId, formID, index, opts)



This function allows you to delete a row from your SecureForm database, based on the row index. This function will delete the row and any associated files.  This API call is audited: a record will be made of the particular API Integration and IP address that “deleted” each matching row (also implying that any associated files have been removed). {{ACL: Account: SecureForm Database - Delete}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let index = "index_example"; // String | 
let opts = { 
};
apiInstance.deleteSecureFormDatabaseRow(accountId, formID, index, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **index** | **String**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureForm"></a>
# **getSecureForm**
> InlineResponse20067 getSecureForm(accountId, formID, opts)



Returns details on a specific SecureForm configuration, based on the configuration’s unique ID.  {{ACL: Account: SecureForm Configuration}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let opts = { 
};
apiInstance.getSecureForm(accountId, formID, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 

### Return type

[**InlineResponse20067**](InlineResponse20067.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureFormDatabaseFile"></a>
# **getSecureFormDatabaseFile**
> InlineResponse20071 getSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex, opts)



This function is used to retrieve a file associated with a row in your SecureForm database. You will need the row index and the file ID (which you can retrieve by reading the row data using other API calls).  If the file was encrypted at rest in the database, it will be decrypted for you.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each file. {{ACL: Account: SecureForm Database - Read}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let rowIndex = "rowIndex_example"; // String | 
let fileIndex = "fileIndex_example"; // String | 
let opts = { 
};
apiInstance.getSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **rowIndex** | **String**|  | 
 **fileIndex** | **String**|  | 

### Return type

[**InlineResponse20071**](InlineResponse20071.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureFormDatabasePosts"></a>
# **getSecureFormDatabasePosts**
> InlineResponse20068 getSecureFormDatabasePosts(accountId, formID, opts)



Returns details on the posts currently stored in the database table associated with a specific SecureForm configuration. This function is recommended for use when synchronizing or periodically downloading new rows to an external source: it allows you to quickly and easily see what, if any, entries are new relative to your last actions (if you saved the last index or date when you previously downloaded data).  You can optionally pass one or more parameters to narrow down the scope of what rows are examined to produce the summary results. By default, all table rows are examined. All criteria passed as parameters are used; it is possible (and easy) to specify mutually exclusive parameters that result in no rows being examined (e.g. all rows with an index greater than 100 and less than 50). {{ACL: Account: SecureForm Database - Read}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  'afterIndex': 56, // Number | All rows whose index is greater than the specified value
  'beforeDate': "beforeDate_example", // String | DATETIME. All rows added before the specified date time
  'beforeIndex': 56, // Number | All rows whose index is less than the specified value
  'fromDate': "fromDate_example", // String | DATETIME. All rows added on or after the specified date time
  'fromIndex': 56, // Number | All rows whose index is greater than or equal to the specified value.
  'throughDate': "throughDate_example", // String | DATETIME. All rows added on or before the specified date time
  'throughIndex': 56, // Number | All rows whose index is less than or equal to the specified value.
};
apiInstance.getSecureFormDatabasePosts(accountId, formID, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **afterDate** | **String**| DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional] 
 **afterIndex** | **Number**| All rows whose index is greater than the specified value | [optional] 
 **beforeDate** | **String**| DATETIME. All rows added before the specified date time | [optional] 
 **beforeIndex** | **Number**| All rows whose index is less than the specified value | [optional] 
 **fromDate** | **String**| DATETIME. All rows added on or after the specified date time | [optional] 
 **fromIndex** | **Number**| All rows whose index is greater than or equal to the specified value. | [optional] 
 **throughDate** | **String**| DATETIME. All rows added on or before the specified date time | [optional] 
 **throughIndex** | **Number**| All rows whose index is less than or equal to the specified value. | [optional] 

### Return type

[**InlineResponse20068**](InlineResponse20068.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureFormDatabaseRow"></a>
# **getSecureFormDatabaseRow**
> InlineResponse20070 getSecureFormDatabaseRow(accountId, formID, index, opts)



This function works the same as “Get SecureForm Database Rows”, except that you specify the row index and get back up to 1 row. This index is the &#x60;\\_\\_index\\_\\_&#x60; field for the row.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  {{ACL: Account: SecureForm Database - Read}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let index = "index_example"; // String | 
let opts = { 
};
apiInstance.getSecureFormDatabaseRow(accountId, formID, index, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **index** | **String**|  | 

### Return type

[**InlineResponse20070**](InlineResponse20070.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureFormDatabaseRows"></a>
# **getSecureFormDatabaseRows**
> InlineResponse20069 getSecureFormDatabaseRows(accountId, formID, opts)



This function returns the actual content of all database rows matching your query. Encrypted database fields will be automatically decrypted and the actual values of the fields returned.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  You can optionally pass one or more parameters to narrow down the scope of what rows are returned. These parameters are the same as those for “Get SecureForm Database Info”. {{ACL: Account: SecureForm Database - Read}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let formID = "formID_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”).
  'afterIndex': 56, // Number | All rows whose index is greater than the specified value
  'beforeDate': "beforeDate_example", // String | DATETIME. All rows added before the specified date time
  'beforeIndex': 56, // Number | All rows whose index is less than the specified value
  'fromDate': "fromDate_example", // String | DATETIME. All rows added on or after the specified date time
  'fromIndex': 56, // Number | All rows whose index is greater than or equal to the specified value.
  'throughDate': "throughDate_example", // String | DATETIME. All rows added on or before the specified date time
  'throughIndex': 56, // Number | All rows whose index is less than or equal to the specified value.
};
apiInstance.getSecureFormDatabaseRows(accountId, formID, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **formID** | **String**|  | 
 **afterDate** | **String**| DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional] 
 **afterIndex** | **Number**| All rows whose index is greater than the specified value | [optional] 
 **beforeDate** | **String**| DATETIME. All rows added before the specified date time | [optional] 
 **beforeIndex** | **Number**| All rows whose index is less than the specified value | [optional] 
 **fromDate** | **String**| DATETIME. All rows added on or after the specified date time | [optional] 
 **fromIndex** | **Number**| All rows whose index is greater than or equal to the specified value. | [optional] 
 **throughDate** | **String**| DATETIME. All rows added on or before the specified date time | [optional] 
 **throughIndex** | **Number**| All rows whose index is less than or equal to the specified value. | [optional] 

### Return type

[**InlineResponse20069**](InlineResponse20069.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSecureFormList"></a>
# **getSecureFormList**
> InlineResponse20066 getSecureFormList(accountId, opts)



Return a list of all SecureForm configurations currently defined in your account. {{ACL: Account: SecureForm Configuration}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.SecureFormApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getSecureFormList(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20066**](InlineResponse20066.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

