# Luxsci.ReportsApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAccountJob**](ReportsApi.md#getAccountJob) | **GET** /account/{accountId}/job/{job_id} | 
[**getAccountJobs**](ReportsApi.md#getAccountJobs) | **GET** /account/{accountId}/jobs | 
[**getAccountSuppressionReport**](ReportsApi.md#getAccountSuppressionReport) | **GET** /account/{accountId}/suppression_v2/ | 
[**getAccountSuppressionSummaryReport**](ReportsApi.md#getAccountSuppressionSummaryReport) | **GET** /account/{accountId}/suppression_count/ | 
[**getEmailFeedBackLoopsReportAccount**](ReportsApi.md#getEmailFeedBackLoopsReportAccount) | **GET** /account/{accountId}/report/email/fbl | 
[**getEmailFeedBackLoopsSummaryReportAccount**](ReportsApi.md#getEmailFeedBackLoopsSummaryReportAccount) | **GET** /account/{accountId}/report/email/fbl_count | 
[**getEmailSMTPClickReportAccount**](ReportsApi.md#getEmailSMTPClickReportAccount) | **GET** /account/{accountId}/report/email/smtp/clicks | 
[**getEmailSMTPClickSummaryReportAccount**](ReportsApi.md#getEmailSMTPClickSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/clicks_count | 
[**getEmailSMTPDeliveryStatusReportAccount**](ReportsApi.md#getEmailSMTPDeliveryStatusReportAccount) | **GET** /account/{accountId}/report/email/smtp/delivery | 
[**getEmailSMTPDeliveryStatusSummaryReportAccount**](ReportsApi.md#getEmailSMTPDeliveryStatusSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/delivery_count | 
[**getEmailSMTPOpenReportAccount**](ReportsApi.md#getEmailSMTPOpenReportAccount) | **GET** /account/{accountId}/report/email/smtp/opens | 
[**getEmailSMTPOpenSummaryReportAccount**](ReportsApi.md#getEmailSMTPOpenSummaryReportAccount) | **GET** /account/{accountId}/report/email/smtp/opens_count | 
[**getEmailSMTPSentReportAccount**](ReportsApi.md#getEmailSMTPSentReportAccount) | **GET** /account/{accountId}/report/email/smtp/sent | 
[**getEmailSMTPTempFailReportAccount**](ReportsApi.md#getEmailSMTPTempFailReportAccount) | **GET** /account/{accountId}/report/email/smtp/temp_fail | 
[**getEmailWebMailClickReportAccount**](ReportsApi.md#getEmailWebMailClickReportAccount) | **GET** /account/{accountId}/report/email/webmail/clicks | 
[**getEmailWebMailDeliveryStatusReportAccount**](ReportsApi.md#getEmailWebMailDeliveryStatusReportAccount) | **GET** /account/{accountId}/report/email/webmail/delivery | 
[**getEmailWebMailOpenReportAccount**](ReportsApi.md#getEmailWebMailOpenReportAccount) | **GET** /account/{accountId}/report/email/webmail/opens | 
[**getEmailWebMailSentReportAccount**](ReportsApi.md#getEmailWebMailSentReportAccount) | **GET** /account/{accountId}/report/email/webmail/sent | 
[**getSMTPLoginFailureReportAccount**](ReportsApi.md#getSMTPLoginFailureReportAccount) | **GET** /account/{accountId}/report/login_fail/smtp | 

<a name="getAccountJob"></a>
# **getAccountJob**
> InlineResponse20033 getAccountJob(accountId, jobId, opts)



Return the details of a specific asynchronous reporting job. If the job_id is not found, a not found API error will be emitted.

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let jobId = 56; // Number | 
let opts = { 
};
apiInstance.getAccountJob(accountId, jobId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **jobId** | **Number**|  | 

### Return type

[**InlineResponse20033**](InlineResponse20033.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAccountJobs"></a>
# **getAccountJobs**
> InlineResponse20032 getAccountJobs(accountId, opts)



Return a list of all asynchronous reporting jobs submitted by this account in the past 7 days.

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
};
apiInstance.getAccountJobs(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 

### Return type

[**InlineResponse20032**](InlineResponse20032.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAccountSuppressionReport"></a>
# **getAccountSuppressionReport**
> InlineResponse20021 getAccountSuppressionReport(accountId, opts)



Retrieve all email suppressions at the account level (only) using a report-style call.  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response.](/rest-api/report-responses.html#sup). {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'email': "email_example", // String | Restrict the report to suppressions of this specific email address.
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example" // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
};
apiInstance.getAccountSuppressionReport(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **email** | **String**| Restrict the report to suppressions of this specific email address. | [optional] 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAccountSuppressionSummaryReport"></a>
# **getAccountSuppressionSummaryReport**
> InlineResponse20021 getAccountSuppressionSummaryReport(accountId, opts)



Retrieve a count of the matching email suppressions at the account level (only) using a report-style call.  Dates are based on the date that the suppression was added.  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#sup_count)   {{ACL: User Email: Suppression}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'filter1': "filter1_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter2': "filter2_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter3': "filter3_example" // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
};
apiInstance.getAccountSuppressionSummaryReport(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **filter1** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter2** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter3** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailFeedBackLoopsReportAccount"></a>
# **getEmailFeedBackLoopsReportAccount**
> InlineResponse20021 getEmailFeedBackLoopsReportAccount(accountId, opts)



This report allows to see what messages that you have sent successfully have been “marked as spam” by recipients and this information has come back to us via one of our feedback loops. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#fbl). {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF-8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Restrict the report to the user with this specific User ID number.
};
apiInstance.getEmailFeedBackLoopsReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF-8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Restrict the report to the user with this specific User ID number. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailFeedBackLoopsSummaryReportAccount"></a>
# **getEmailFeedBackLoopsSummaryReportAccount**
> InlineResponse20021 getEmailFeedBackLoopsSummaryReportAccount(accountId, opts)



This report allows to see how many messages have been marked as spam.  The date of the compliant is used for date filters. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#fbl_count). {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'filter1': "filter1_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter2': "filter2_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter3': "filter3_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'from': "from_example", // String | String Case-insensitive substring search of the message “From” email address
  'subject': "subject_example", // String | String Case-insensitive substring search of the message subject (in UTF-8).
  'to': "to_example", // String | String. Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Integer Restrict the report to the user with this specific User ID number.
};
apiInstance.getEmailFeedBackLoopsSummaryReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **filter1** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter2** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter3** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **from** | **String**| String Case-insensitive substring search of the message “From” email address | [optional] 
 **subject** | **String**| String Case-insensitive substring search of the message subject (in UTF-8). | [optional] 
 **to** | **String**| String. Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Integer Restrict the report to the user with this specific User ID number. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPClickReportAccount"></a>
# **getEmailSMTPClickReportAccount**
> InlineResponse20021 getEmailSMTPClickReportAccount(accountId, opts)



This report allows you to query on the “URL click” events (or lack thereof) for email messages sent via SMTP that have email click tracking enabled. Using this command, it is possible to get a report of all individual clicks or to get reports about messages that have not yet been clicked on or for which click tracking was not enabled. See the query parameters for more detail.  *Note: if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.*  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#click).  Dates, for the purposes of narrowing results, refer to the date the message was sent. This corresponds to the “date_sent” output field. However, if you set the “click_date” input parameter to true, then the “click_date” field will be used for date selections. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'clicked': 56, // Number | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  'clickDate': "clickDate_example", // String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 56, // Number | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  'sendmailId': "sendmailId_example", // String | String. Return only the messages with the specified sendmail_id
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'status': "status_example", // String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
  'url': "url_example", // String | Substring match on the URL clicked.
};
apiInstance.getEmailSMTPClickReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **clicked** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;clicked &lt; 0 – select messages where click tracking was not enabled.&lt;br&gt;clicked &#x3D; 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.&lt;br&gt;clicked &gt; 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,&lt;i&gt;you can get multiple rows per message&lt;/i&gt;.&lt;br&gt;&lt;br&gt;If a value for “clicked” is not specified, a value of “1” will be assumed. | [optional] 
 **clickDate** | **String**| If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used. | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled, and which have been opened at least once.  | [optional] 
 **sendmailId** | **String**| String. Return only the messages with the specified sendmail_id | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **status** | **String**| Values:&lt;br&gt;&lt;b&gt;delivered&lt;/b&gt; – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.&lt;br&gt;&lt;b&gt;perm_fail&lt;/b&gt; – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.&lt;br&gt;&lt;b&gt;lost&lt;/b&gt; – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.&lt;br&gt;&lt;b&gt;queued&lt;/b&gt; – Message is in the email server queue still waiting to be delivered to the recipient.&lt;br&gt;&lt;b&gt;not_queued&lt;/b&gt; -- all statuses except \&quot;queued\&quot;. &lt;br&gt;&lt;b&gt;ba_soft_fail&lt;/b&gt; – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).&lt;br&gt;&lt;b&gt;ba_hard_fail&lt;/b&gt; – Hard failure bounces received after successful delivery to the recipient’s servers,&lt;br&gt;&lt;b&gt;any_hard_fail&lt;/b&gt; – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures. | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 
 **url** | **String**| Substring match on the URL clicked. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPClickSummaryReportAccount"></a>
# **getEmailSMTPClickSummaryReportAccount**
> InlineResponse20021 getEmailSMTPClickSummaryReportAccount(accountId, opts)



This report allows you to query the number of clicks on tracked links during the specified date period. *Note that if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.* See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#clicks_count). Dates, for the purposes of narrowing results, refer to the date the link was clicked on.  {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'filter1': "filter1_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter2': "filter2_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter3': "filter3_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
  'url': "url_example", // String | Substring match on the URL clicked.
};
apiInstance.getEmailSMTPClickSummaryReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **filter1** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter2** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter3** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 
 **url** | **String**| Substring match on the URL clicked. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPDeliveryStatusReportAccount"></a>
# **getEmailSMTPDeliveryStatusReportAccount**
> InlineResponse20021 getEmailSMTPDeliveryStatusReportAccount(accountId, opts)



This report allows you to see how each SMTP message was sent to each recipient and what the delivery status is for each of these recipients. Note that delivery status changes over time as messages progress to the recipient’s servers and as bounce messages are sent back and processed. As the delivery status changes, the “last_update” date is also updated.  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#delivery).  Dates, for the purposes of narrowing results, refer to the *date the row was last updated*. This corresponds to the last_update output field. This can be changed to the date the message was sent using the \&quot;sent_date\&quot; parameter or the date of the last delivery status update using the \&quot;delivery_date\&quot; parameter. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'clicked': 56, // Number | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  'from': "from_example", // String | String. Case-insensitive substring search of the message “From” email Address
  'ip': "ip_example", // String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 56, // Number | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  'secureline': "secureline_example", // String | Enum. Value:<br>u - message to this recipient did not use SecureLine (or Opt Out was used)<br>e - message did use SecureLine<br>-2 - SecureLine was not used due to Opt Out being selected<br>-1 - SecureLine usage not recorded for some reason<br>1 - SecureLine:PGP was used<br>2 - SecureLine:S/MIME was used<br>3 - SecureLine:Escrow was used<br>4 - SecureLine:TLS was used
  'sendmailId': "sendmailId_example", // String | String. Return only the messages with the specified sendmail_id
  'sentDate': 56, // Number | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the row.
  'state': "state_example", // String | Optionally, match only messages with a specific delivery state/status.  Supported values include: \"delivered\" - message successfully delivered to recipient email servers; \"any_hard_fail\" - Either status: \"perm_fail\" or \"ba_hard_fail\"; \"lost\" - Message delivery status not determined; \"queued\" - Message currently queued for delivery (includes message status \"received\", \"queued\", and \"temp_fail\"); \"not_quueed\" - Message is no longer queued for delivery (it has been delivered, bounced, or failed); \"perm_fail\" - Message delivery rejected by the recipient servers; \"ba_soft_fail\" - A post-delivery soft bounce failure email message was received; \"ba_had_fail\" - A post-delivery hard bounce failure email message was received.
  'stateDetail': "stateDetail_example", // String | Optionally, match only messages where the \"state_detail\" delivery status description contains the specified text (case insensitive).
  'deliveryDate': 56, // Number | If set to true (i.e., 1), the email message last delivery status updated date will be used for date/time selections, instead of the date of the last update of the row.
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'spam': 56, // Number | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  'unsubscribed': 56, // Number | Enum. Value:<br>0 – Recipient did not unsubscribe based on this email message.<br>1 – Recipeient did unsubscribe based on this email message.
  'smtpCode': "smtpCode_example", // String | String. 1-3 characters.  Substring match to the beginning of the smtp_code field.  E.g., 5 matches all codes starting with 5.
  'tls': 56, // Number | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Integer. Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailSMTPDeliveryStatusReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **clicked** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;clicked &lt; 0 – select messages where URL click tracking was not enabled.&lt;br&gt;clicked &#x3D; 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.&lt;br&gt;clicked &gt; 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on. | [optional] 
 **from** | **String**| String. Case-insensitive substring search of the message “From” email Address | [optional] 
 **ip** | **String**| String. Case-insensitive substring search of the sender IP address (for SMTP reports only). | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened. | [optional] 
 **secureline** | **String**| Enum. Value:&lt;br&gt;u - message to this recipient did not use SecureLine (or Opt Out was used)&lt;br&gt;e - message did use SecureLine&lt;br&gt;-2 - SecureLine was not used due to Opt Out being selected&lt;br&gt;-1 - SecureLine usage not recorded for some reason&lt;br&gt;1 - SecureLine:PGP was used&lt;br&gt;2 - SecureLine:S/MIME was used&lt;br&gt;3 - SecureLine:Escrow was used&lt;br&gt;4 - SecureLine:TLS was used | [optional] 
 **sendmailId** | **String**| String. Return only the messages with the specified sendmail_id | [optional] 
 **sentDate** | **Number**| If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the row. | [optional] 
 **state** | **String**| Optionally, match only messages with a specific delivery state/status.  Supported values include: \&quot;delivered\&quot; - message successfully delivered to recipient email servers; \&quot;any_hard_fail\&quot; - Either status: \&quot;perm_fail\&quot; or \&quot;ba_hard_fail\&quot;; \&quot;lost\&quot; - Message delivery status not determined; \&quot;queued\&quot; - Message currently queued for delivery (includes message status \&quot;received\&quot;, \&quot;queued\&quot;, and \&quot;temp_fail\&quot;); \&quot;not_quueed\&quot; - Message is no longer queued for delivery (it has been delivered, bounced, or failed); \&quot;perm_fail\&quot; - Message delivery rejected by the recipient servers; \&quot;ba_soft_fail\&quot; - A post-delivery soft bounce failure email message was received; \&quot;ba_had_fail\&quot; - A post-delivery hard bounce failure email message was received. | [optional] 
 **stateDetail** | **String**| Optionally, match only messages where the \&quot;state_detail\&quot; delivery status description contains the specified text (case insensitive). | [optional] 
 **deliveryDate** | **Number**| If set to true (i.e., 1), the email message last delivery status updated date will be used for date/time selections, instead of the date of the last update of the row. | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **spam** | **Number**| Enum. Value:&lt;br&gt;0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.&lt;br&gt;1 – Message was marked as spam by a recipient and returned in a Feed Back Loop | [optional] 
 **unsubscribed** | **Number**| Enum. Value:&lt;br&gt;0 – Recipient did not unsubscribe based on this email message.&lt;br&gt;1 – Recipeient did unsubscribe based on this email message. | [optional] 
 **smtpCode** | **String**| String. 1-3 characters.  Substring match to the beginning of the smtp_code field.  E.g., 5 matches all codes starting with 5. | [optional] 
 **tls** | **Number**| Enum. Value:&lt;br&gt;0 – TLS was NOT used in the successful delivery of this message to the recipient server&lt;br&gt;1 – TLS was used in the successful delivery of this message to the recipient server | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Integer. Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPDeliveryStatusSummaryReportAccount"></a>
# **getEmailSMTPDeliveryStatusSummaryReportAccount**
> InlineResponse20021 getEmailSMTPDeliveryStatusSummaryReportAccount(accountId, opts)



This report allows you to retrieve a summary of the delivery status (and other statistics) across all messages in a given time range. See also [API Reporting Basics](/rest-api/reporting.html)  and [report header columns in the response](/rest-api/report-responses.html#delivery_count). Dates, for the purposes of narrowing results, refer to the *date the message delivery status was last updated*. This can be changed to the date the message was sent using the \&quot;sent_date\&quot; parameter. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'filter1': "filter1_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter2': "filter2_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter3': "filter3_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'clicked': 56, // Number | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  'from': "from_example", // String | String. Case-insensitive substring search of the message “From” email Address
  'ip': "ip_example", // String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 56, // Number | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  'secureline': "secureline_example", // String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  'sentDate': 56, // Number | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  'queueAgeSec': 56, // Number | If provided, then the \"queued\" and \"pct_queued\" results will reflect only those messages that have been not delivered for at least this number of seconds.  I.e., use this to eliminate very recently sent messages from your analysis or how mange messages were queued and not yet delivered.
  'unsubscribed': 56, // Number | Enum. Value: 0 – The recipient did not unsubscribe based on this email message. 1 – The recipient did unsubscribe based on this email message.
  'tls': 56, // Number | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Integer. Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailSMTPDeliveryStatusSummaryReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **filter1** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter2** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter3** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **clicked** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;clicked &lt; 0 – select messages where URL click tracking was not enabled.&lt;br&gt;clicked &#x3D; 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.&lt;br&gt;clicked &gt; 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on. | [optional] 
 **from** | **String**| String. Case-insensitive substring search of the message “From” email Address | [optional] 
 **ip** | **String**| String. Case-insensitive substring search of the sender IP address (for SMTP reports only). | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened. | [optional] 
 **secureline** | **String**| Enum. Value:&lt;br&gt;u – Message to this recipient did not use SecureLine (or Opt Out was used)&lt;br&gt;e – Message did use SecureLine&lt;br&gt;-2 – SecureLine was not used due to Opt Out being selected&lt;br&gt;-1 – SecureLine usage not recorded for some reason&lt;br&gt;1 – SecureLine:PGP was used&lt;br&gt;2 – SecureLine:S/MIME was used&lt;br&gt;3 – SecureLine:Escrow was used&lt;br&gt;4 – SecureLine:TLS was used | [optional] 
 **sentDate** | **Number**| If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status. | [optional] 
 **queueAgeSec** | **Number**| If provided, then the \&quot;queued\&quot; and \&quot;pct_queued\&quot; results will reflect only those messages that have been not delivered for at least this number of seconds.  I.e., use this to eliminate very recently sent messages from your analysis or how mange messages were queued and not yet delivered. | [optional] 
 **unsubscribed** | **Number**| Enum. Value: 0 – The recipient did not unsubscribe based on this email message. 1 – The recipient did unsubscribe based on this email message. | [optional] 
 **tls** | **Number**| Enum. Value:&lt;br&gt;0 – TLS was NOT used in the successful delivery of this message to the recipient server&lt;br&gt;1 – TLS was used in the successful delivery of this message to the recipient server. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Integer. Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPOpenReportAccount"></a>
# **getEmailSMTPOpenReportAccount**
> InlineResponse20021 getEmailSMTPOpenReportAccount(accountId, opts)



This report allows you to query on the “opened” events (or lack thereof) for email messages sent via SMTP that have email open tracking enabled. Using this command, it is possible to get a report of all individual opens for messages or to get reports about messages that have not yet been opened or for which open tracking was not enabled. See the query parameters for more detail.  *Note: if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.*  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#open).  Dates, for the purposes of narrowing results, refer to the date the message was sent. This corresponds to the “date_sent” output field. However, if you set the “open_date” input parameter to true, then the “open_date” field will be used for date selections. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 1, // Number | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  'openDate': true, // Boolean | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  'sendmailId': "sendmailId_example", // String | Return only the messages with the specified sendmail_id.
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'status': "status_example", // String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailSMTPOpenReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, &lt;i&gt;you can get multiple rows per message&lt;/i&gt;.&lt;br&gt;&lt;br&gt;If you do not specify a value for “opened”, a value of “1” will be assumed. | [optional] [default to 1]
 **openDate** | **Boolean**| If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used. | [optional] 
 **sendmailId** | **String**| Return only the messages with the specified sendmail_id. | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **status** | **String**| Values:&lt;br&gt;&lt;b&gt;delivered&lt;/b&gt; – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.&lt;br&gt;&lt;b&gt;perm_fail&lt;/b&gt; – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.&lt;br&gt;&lt;b&gt;lost&lt;/b&gt; – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.&lt;br&gt;&lt;b&gt;queued&lt;/b&gt; – Message is in the email server queue still waiting to be delivered to the recipient.&lt;br&gt;&lt;b&gt;not_queued&lt;/b&gt; -- all statuses except \&quot;queued\&quot;. &lt;br&gt;&lt;b&gt;ba_soft_fail&lt;/b&gt; – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).&lt;br&gt;&lt;b&gt;ba_hard_fail&lt;/b&gt; – Hard failure bounces received after successful delivery to the recipient’s servers,&lt;br&gt;&lt;b&gt;any_hard_fail&lt;/b&gt; – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures. | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPOpenSummaryReportAccount"></a>
# **getEmailSMTPOpenSummaryReportAccount**
> InlineResponse20021 getEmailSMTPOpenSummaryReportAccount(accountId, opts)



This report allows returns the number of opens that happened in the selected time period. See [report header columns in the response](/rest-api/report-responses.html#opens_count). *Note: if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.* Dates, for the purposes of narrowing results, refer to the date the message was opened.  {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'filter1': "filter1_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter2': "filter2_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'filter3': "filter3_example", // String | Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 1, // Number | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailSMTPOpenSummaryReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **filter1** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter2** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **filter3** | **String**| Control when a summary report returns values (for use with automated reports). See https://luxsci.com/rest-api/reporting.html#filters | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, &lt;i&gt;you can get multiple rows per message&lt;/i&gt;.&lt;br&gt;&lt;br&gt;If you do not specify a value for “opened”, a value of “1” will be assumed. | [optional] [default to 1]
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPSentReportAccount"></a>
# **getEmailSMTPSentReportAccount**
> InlineResponse20021 getEmailSMTPSentReportAccount(accountId, opts)



Return a list of all email messages sent sent via SMTP by users in this account. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#sent). {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'ip': "ip_example", // String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  'optOut': "optOut_example", // String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  'secureline': "secureline_example", // String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  'sendmailId': "sendmailId_example", // String | Return only the message with the specified sendmail_id.
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'spam': "spam_example", // String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF-8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'templateId': 56, // Number | Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number.
};
apiInstance.getEmailSMTPSentReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **ip** | **String**| Case-insensitive substring search of the sender IP address (for SMTP reports only). | [optional] 
 **optOut** | **String**| Value:&lt;br&gt;0 – SecureLine Opt Out not used&lt;br&gt;-1 – SecureLine Opt Out use not recorded for some reason&lt;br&gt;1 – SecureLine Opt Out | [optional] 
 **secureline** | **String**| Value:&lt;br&gt;any – Match anything&lt;br&gt;-1 – SecureLine usage not recorded for some reason&lt;br&gt;1 – SecureLine encryption was used&lt;br&gt;0 – SecureLine encryption was not used&lt;br&gt;&lt;br&gt;If SecureLine was used, use the delivery status report to see more details. | [optional] 
 **sendmailId** | **String**| Return only the message with the specified sendmail_id. | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **spam** | **String**| Value:&lt;br&gt;0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop&lt;br&gt;1 – Message was marked as spam by a recipient and returned in a Feed Back Loop | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF-8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **templateId** | **Number**| Optional template ID to select results only for those messages sent using the specified template.  A value of 0 selects all. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailSMTPTempFailReportAccount"></a>
# **getEmailSMTPTempFailReportAccount**
> InlineResponse20021 getEmailSMTPTempFailReportAccount(accountId, opts)



This report allows you to download all temporary failure responses that were experienced when trying to deliver a message or messages to recipients.  These provide insight into why it may have taken longer than expected to deliver a specific email message.  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#temp_fail).  {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'sendmailId': "sendmailId_example", // String | String. Return temp failures only the messages with the specified sendmail_id
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns temporary failures for any matching messages.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Integer. Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailSMTPTempFailReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **sendmailId** | **String**| String. Return temp failures only the messages with the specified sendmail_id | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns temporary failures for any matching messages. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Integer. Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailWebMailClickReportAccount"></a>
# **getEmailWebMailClickReportAccount**
> InlineResponse20021 getEmailWebMailClickReportAccount(accountId, opts)



This report allows you to query on the “URL click” events (or lack thereof) for Webmail email messages that have email click tracking enabled. Using this command, it is possible to get a report of all individual clicks or to get reports about messages that have not yet been clicked on or for which click tracking was not enabled. See the query parameters for more detail.  *Note: if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.*  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#click).  Dates, for the purposes of narrowing results, refer to the date the message was sent. This corresponds to the “date_sent” output field. However, if you set the “click_date” input parameter to true, then the “click_date” field will be used for date selections. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'clicked': 56, // Number | If specified, the results are restricted as follows:<br>clicked < 0 – select messages where click tracking was not enabled.<br>clicked = 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.<br>clicked > 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,<i>you can get multiple rows per message</i>.<br><br>If a value for “clicked” is not specified, a value of “1” will be assumed.
  'clickDate': "clickDate_example", // String | If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 56, // Number | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled, and which have been opened at least once. 
  'sendmailId': "sendmailId_example", // String | String. Return only the messages with the specified sendmail_id
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'status': "status_example", // String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
  'url': "url_example", // String | Substring match on the URL clicked.
};
apiInstance.getEmailWebMailClickReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **clicked** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;clicked &lt; 0 – select messages where click tracking was not enabled.&lt;br&gt;clicked &#x3D; 0 – select messages where click tracking was enabled, but where no URLs have yet been clicked by the recipient.&lt;br&gt;clicked &gt; 0 – select messages where one or more URLs have been clicked by the recipient. When “clicked” is positive, you will get one row back for each click; so,&lt;i&gt;you can get multiple rows per message&lt;/i&gt;.&lt;br&gt;&lt;br&gt;If a value for “clicked” is not specified, a value of “1” will be assumed. | [optional] 
 **clickDate** | **String**| If true, the ”click_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used. | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled, and which have been opened at least once.  | [optional] 
 **sendmailId** | **String**| String. Return only the messages with the specified sendmail_id | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **status** | **String**| Values:&lt;br&gt;&lt;b&gt;delivered&lt;/b&gt; – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.&lt;br&gt;&lt;b&gt;perm_fail&lt;/b&gt; – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.&lt;br&gt;&lt;b&gt;lost&lt;/b&gt; – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.&lt;br&gt;&lt;b&gt;queued&lt;/b&gt; – Message is in the email server queue still waiting to be delivered to the recipient.&lt;br&gt;&lt;b&gt;not_queued&lt;/b&gt; -- all statuses except \&quot;queued\&quot;. &lt;br&gt;&lt;b&gt;ba_soft_fail&lt;/b&gt; – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).&lt;br&gt;&lt;b&gt;ba_hard_fail&lt;/b&gt; – Hard failure bounces received after successful delivery to the recipient’s servers,&lt;br&gt;&lt;b&gt;any_hard_fail&lt;/b&gt; – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures. | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 
 **url** | **String**| Substring match on the URL clicked. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailWebMailDeliveryStatusReportAccount"></a>
# **getEmailWebMailDeliveryStatusReportAccount**
> InlineResponse20021 getEmailWebMailDeliveryStatusReportAccount(accountId, opts)



This report allows you to see how each Webmail message was sent to each recipient and what the delivery status is for each of these recipients. Note that delivery status changes over time as messages progress to the recipient’s servers and as bounce messages are sent back and processed. As the delivery status changes, the “last_update” date is also updated.  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#delivery).  Dates, for the purposes of narrowing results, refer to the *date the message delivery status was last updated*. This corresponds to the “last_update” output field.  This can be changed to the date the message was sent using the \&quot;sent_date\&quot; parameter. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'clicked': 56, // Number | Integer. If specified, the results are restricted as follows:<br>clicked < 0 – select messages where URL click tracking was not enabled.<br>clicked = 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.<br>clicked > 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on.
  'from': "from_example", // String | String. Case-insensitive substring search of the message “From” email Address
  'ip': "ip_example", // String | String. Case-insensitive substring search of the sender IP address (for SMTP reports only).
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 56, // Number | Integer. If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened.
  'secureline': "secureline_example", // String | Enum. Value:<br>u – Message to this recipient did not use SecureLine (or Opt Out was used)<br>e – Message did use SecureLine<br>-2 – SecureLine was not used due to Opt Out being selected<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine:PGP was used<br>2 – SecureLine:S/MIME was used<br>3 – SecureLine:Escrow was used<br>4 – SecureLine:TLS was used
  'sendmailId': "sendmailId_example", // String | String. Return only the messages with the specified sendmail_id
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'sentDate': 56, // Number | If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status.
  'spam': 56, // Number | Enum. Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  'tls': 56, // Number | Enum. Value:<br>0 – TLS was NOT used in the successful delivery of this message to the recipient server<br>1 – TLS was used in the successful delivery of this message to the recipient server
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'userId': 56, // Number | Integer. Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailWebMailDeliveryStatusReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **clicked** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;clicked &lt; 0 – select messages where URL click tracking was not enabled.&lt;br&gt;clicked &#x3D; 0 – select messages where URL click tracking was enabled, but where there have as yet been no clicks on any clinks in the messages.&lt;br&gt;clicked &gt; 0 – select messages where URL click tracking was enabled and where there have been N or more clicks on links in the same message to the same recipient. N, in this case, is the number that you have specified as the value of the “clicked” parameter. I.e., using a value of “1” matches all messages that have had a link clicked on. | [optional] 
 **from** | **String**| String. Case-insensitive substring search of the message “From” email Address | [optional] 
 **ip** | **String**| String. Case-insensitive substring search of the sender IP address (for SMTP reports only). | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| Integer. If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least N times. N, in this case, is the number that you have specified as the value of the “opened” parameter. I.e., using a value of “1” matches all messages that have been opened. | [optional] 
 **secureline** | **String**| Enum. Value:&lt;br&gt;u – Message to this recipient did not use SecureLine (or Opt Out was used)&lt;br&gt;e – Message did use SecureLine&lt;br&gt;-2 – SecureLine was not used due to Opt Out being selected&lt;br&gt;-1 – SecureLine usage not recorded for some reason&lt;br&gt;1 – SecureLine:PGP was used&lt;br&gt;2 – SecureLine:S/MIME was used&lt;br&gt;3 – SecureLine:Escrow was used&lt;br&gt;4 – SecureLine:TLS was used | [optional] 
 **sendmailId** | **String**| String. Return only the messages with the specified sendmail_id | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **sentDate** | **Number**| If set to true (i.e., 1), the email message sent date will be used for date/time selections, instead of the date of the last update of the delivery status. | [optional] 
 **spam** | **Number**| Enum. Value:&lt;br&gt;0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop.&lt;br&gt;1 – Message was marked as spam by a recipient and returned in a Feed Back Loop | [optional] 
 **tls** | **Number**| Enum. Value:&lt;br&gt;0 – TLS was NOT used in the successful delivery of this message to the recipient server&lt;br&gt;1 – TLS was used in the successful delivery of this message to the recipient server | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **userId** | **Number**| Integer. Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailWebMailOpenReportAccount"></a>
# **getEmailWebMailOpenReportAccount**
> InlineResponse20021 getEmailWebMailOpenReportAccount(accountId, opts)



This report allows you to query on the “opened” events (or lack thereof) for email messages sent via Webmail that have email open tracking enabled. Using this command, it is possible to get a report of all individual opens for messages or to get reports about messages that have not yet been opened or for which open tracking was not enabled. See the query parameters for more detail.  *Note: if you are using LuxSci Secure Marketing v2 to send your email messages, then normal LuxSci click and open reporting is disabled (and you will not see click and open data in this report). The LuxSci Secure Marketing v2 platform his its own click and open tracking and reporting system and you should look in that interface for reports.*  See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#open).  Dates, for the purposes of narrowing results, refer to the date the message was sent. This corresponds to the “date_sent” output field. However, if you set the “open_date” input parameter to true, then the “open_date” field will be used for date selections. {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'opened': 1, // Number | If specified, the results are restricted as follows:<br>opened < 0 – select messages where open tracking was not enabled.<br>opened = 0 – select messages where open tracking was enabled, but which have not yet been opened.<br>opened > 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, <i>you can get multiple rows per message</i>.<br><br>If you do not specify a value for “opened”, a value of “1” will be assumed.
  'openDate': true, // Boolean | If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used.
  'sendmailId': "sendmailId_example", // String | Return only the messages with the specified sendmail_id.
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'status': "status_example", // String | Values:<br><b>delivered</b> – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.<br><b>perm_fail</b> – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.<br><b>lost</b> – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.<br><b>queued</b> – Message is in the email server queue still waiting to be delivered to the recipient.<br><b>not_queued</b> -- all statuses except \"queued\". <br><b>ba_soft_fail</b> – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).<br><b>ba_hard_fail</b> – Hard failure bounces received after successful delivery to the recipient’s servers,<br><b>any_hard_fail</b> – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures.
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number
};
apiInstance.getEmailWebMailOpenReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **opened** | **Number**| If specified, the results are restricted as follows:&lt;br&gt;opened &lt; 0 – select messages where open tracking was not enabled.&lt;br&gt;opened &#x3D; 0 – select messages where open tracking was enabled, but which have not yet been opened.&lt;br&gt;opened &gt; 0 – select messages where open tracking was enabled and which have been opened at least once. When opened is positive, you will get one row back for each open; so, &lt;i&gt;you can get multiple rows per message&lt;/i&gt;.&lt;br&gt;&lt;br&gt;If you do not specify a value for “opened”, a value of “1” will be assumed. | [optional] [default to 1]
 **openDate** | **Boolean**| If true, the ”open_date” field will be used for all date selections. If false or not specified, the sent date (“date_sent”) will be used. | [optional] 
 **sendmailId** | **String**| Return only the messages with the specified sendmail_id. | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **status** | **String**| Values:&lt;br&gt;&lt;b&gt;delivered&lt;/b&gt; – Accepted by the recipient’s email servers and presumed delivered. If bounce processing is enabled, then this status could change later to ba_soft_fail or ba_hard_fail.&lt;br&gt;&lt;b&gt;perm_fail&lt;/b&gt; – Messages that have permanently failed to be delivered to the recipient’s servers. If bounce processing is on, this status could change shortly to ba_soft_fail, depending on the nature of the failure message.&lt;br&gt;&lt;b&gt;lost&lt;/b&gt; – Messages where the tracking was lost and it is unclear if it was delivered or lost from the queue.&lt;br&gt;&lt;b&gt;queued&lt;/b&gt; – Message is in the email server queue still waiting to be delivered to the recipient.&lt;br&gt;&lt;b&gt;not_queued&lt;/b&gt; -- all statuses except \&quot;queued\&quot;. &lt;br&gt;&lt;b&gt;ba_soft_fail&lt;/b&gt; – Soft failure bounces received (when talking to the recipient’s servers or after successful delivery to the recipient’s servers).&lt;br&gt;&lt;b&gt;ba_hard_fail&lt;/b&gt; – Hard failure bounces received after successful delivery to the recipient’s servers,&lt;br&gt;&lt;b&gt;any_hard_fail&lt;/b&gt; – Results for ba_hard_fail OR perm_fail. I.e., all hard/permanent failures. | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailWebMailSentReportAccount"></a>
# **getEmailWebMailSentReportAccount**
> InlineResponse20021 getEmailWebMailSentReportAccount(accountId, opts)



Return a list of all WebMail email messages sent by users in this account. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#sent). {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'from': "from_example", // String | Case-insensitive substring search of the message “From” email address
  'header1': "header1_example", // String | Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.<br><br>NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration > Email” area of the LuxSci user interface.
  'header1Operator': "header1Operator_example", // String | If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:<ul> <li>is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value</li> <li>not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value</li> <li>like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value</li> <li>notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value</li></ul>I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:<ul><li>header1 = “X-My-Header”</li><li>header1_operator = “is”</li><li>header1_value = “gh6577hh-abc”</li></ul>Or by passing:<ul><li>header1 = “X-My-Header”,/li><li>header1_operator = “like”</li><li>header1_value = “abc”</li>
  'header1Value': "header1Value_example", // String | Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message.
  'header2': "header2_example", // String | Like “header1” but applies to searching the header 2 column.
  'header2Operator': "header2Operator_example", // String | Like “header1_operator” but applies to searching the header 2 column.
  'header2Value': "header2Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'header3': "header3_example", // String | Like “header1” but applies to searching the header 3 column.
  'header3Operator': "header3Operator_example", // String | Like “header1_operator” but applies to searching the header 3 column.
  'header3Value': "header3Value_example", // String | Like “header1_value” but applies to searching the header 2 column.
  'ip': "ip_example", // String | Case-insensitive substring search of the sender IP address (for SMTP reports only).
  'optOut': "optOut_example", // String | Value:<br>0 – SecureLine Opt Out not used<br>-1 – SecureLine Opt Out use not recorded for some reason<br>1 – SecureLine Opt Out
  'secureline': "secureline_example", // String | Value:<br>any – Match anything<br>-1 – SecureLine usage not recorded for some reason<br>1 – SecureLine encryption was used<br>0 – SecureLine encryption was not used<br><br>If SecureLine was used, use the delivery status report to see more details.
  'sendmailId': "sendmailId_example", // String | Return only the message with the specified sendmail_id.
  'sendmailIds': "sendmailIds_example", // String | Comma-delimited list of up to 100 sendmail ids. Returns any matching messages.
  'spam': "spam_example", // String | Value:<br>0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop<br>1 – Message was marked as spam by a recipient and returned in a Feed Back Loop
  'subject': "subject_example", // String | Case-insensitive substring search of the message subject (in UTF-8).
  'to': "to_example", // String | Case-insensitive substring search of all recipient email addresses.
  'trackedHeaders': "trackedHeaders_example", // String | If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data.
  'userId': "userId_example", // String | Restrict the report to the user with this specific User ID number.
};
apiInstance.getEmailWebMailSentReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **from** | **String**| Case-insensitive substring search of the message “From” email address | [optional] 
 **header1** | **String**| Case-insensitive name of the custom email header field to match against in the “header 1” column. I.e., if you were matching against “X-My-Header” and saving this in header 1, you would enter “X-My-Header” as the value here.&lt;br&gt;&lt;br&gt;NOTE: Data is only stored in the customer header capturing fields/columns if you have explicitly enabled this feature in the “Account Administration &gt; Email” area of the LuxSci user interface. | [optional] 
 **header1Operator** | **String**| If this is present and one of the following 4 values, then the query will only return messages that included “header1” when “header1” was being tracked, and which also satisfy the follow the criteria:&lt;ul&gt; &lt;li&gt;is --- The value of the email header named “header1” in the send email must have been exactly the same as header1_value&lt;/li&gt; &lt;li&gt;not – The value of the email header named “header1” in the send email must not be exactly the same as header1_value&lt;/li&gt; &lt;li&gt;like – The value of the email header named “header1” in the send email must contain (case insensitive) the value in header1_value&lt;/li&gt; &lt;li&gt;notlike – The value of the email header named “header1” in the send email must not contain (case insensitive) the value in header1_value&lt;/li&gt;&lt;/ul&gt;I.e., if you configured your account to capture the value of the header “X-My-Header” and saving this in “header column 1” and an email was sent with the header “X-My-Header: gh6577hh-abc”. This would have been stored in the database. You could then find this message by passing to this API function:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”&lt;/li&gt;&lt;li&gt;header1_operator &#x3D; “is”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “gh6577hh-abc”&lt;/li&gt;&lt;/ul&gt;Or by passing:&lt;ul&gt;&lt;li&gt;header1 &#x3D; “X-My-Header”,/li&gt;&lt;li&gt;header1_operator &#x3D; “like”&lt;/li&gt;&lt;li&gt;header1_value &#x3D; “abc”&lt;/li&gt; | [optional] 
 **header1Value** | **String**| Text used with “header1_operator” for matching the value of the email header specified in the “header1” parameter in the original sent message. | [optional] 
 **header2** | **String**| Like “header1” but applies to searching the header 2 column. | [optional] 
 **header2Operator** | **String**| Like “header1_operator” but applies to searching the header 2 column. | [optional] 
 **header2Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **header3** | **String**| Like “header1” but applies to searching the header 3 column. | [optional] 
 **header3Operator** | **String**| Like “header1_operator” but applies to searching the header 3 column. | [optional] 
 **header3Value** | **String**| Like “header1_value” but applies to searching the header 2 column. | [optional] 
 **ip** | **String**| Case-insensitive substring search of the sender IP address (for SMTP reports only). | [optional] 
 **optOut** | **String**| Value:&lt;br&gt;0 – SecureLine Opt Out not used&lt;br&gt;-1 – SecureLine Opt Out use not recorded for some reason&lt;br&gt;1 – SecureLine Opt Out | [optional] 
 **secureline** | **String**| Value:&lt;br&gt;any – Match anything&lt;br&gt;-1 – SecureLine usage not recorded for some reason&lt;br&gt;1 – SecureLine encryption was used&lt;br&gt;0 – SecureLine encryption was not used&lt;br&gt;&lt;br&gt;If SecureLine was used, use the delivery status report to see more details. | [optional] 
 **sendmailId** | **String**| Return only the message with the specified sendmail_id. | [optional] 
 **sendmailIds** | **String**| Comma-delimited list of up to 100 sendmail ids. Returns any matching messages. | [optional] 
 **spam** | **String**| Value:&lt;br&gt;0 – Message was not marked as spam by a recipient and returned in a Feed Back Loop&lt;br&gt;1 – Message was marked as spam by a recipient and returned in a Feed Back Loop | [optional] 
 **subject** | **String**| Case-insensitive substring search of the message subject (in UTF-8). | [optional] 
 **to** | **String**| Case-insensitive substring search of all recipient email addresses. | [optional] 
 **trackedHeaders** | **String**| If true and this report is for messages sent vis SMTP, then the results will include the six additional fields (header1, header2, header3, header1_value, header2_value, header3_value) which are used to track custom email message header data. | [optional] 
 **userId** | **String**| Restrict the report to the user with this specific User ID number. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSMTPLoginFailureReportAccount"></a>
# **getSMTPLoginFailureReportAccount**
> InlineResponse20021 getSMTPLoginFailureReportAccount(accountId, opts)



This report allows to see all SMTP login failures, as well as sending errors that resulted from our servers explicitly rejecting your request to send an email message for one reason or another. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#smtp_login_fail). {{ACL: Account: View Reports}}

### Example
```javascript
import {Luxsci} from 'luxsci';

const secret_key = "SECRET_KEY";
const token = "TOKEN";

const luxsciClient = await Luxsci.Client({
  publicToken:token,
  privateToken:secret_key
});
let apiInstance = luxsciClient.ReportsApi

let accountId = "accountId_example"; // String | 
let opts = { 
  'afterDate': "afterDate_example", // String | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT
  'beforeDate': "beforeDate_example", // String | DATETIME. Return only matches dated before this date time.
  'firstRow': 0, // Number | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999.
  'fromDate': "fromDate_example", // String | DATETIME. Return only matches dated on or after this date time.
  'matches': 50000, // Number | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets.
  'throughDate': "throughDate_example", // String | DATETIME. Return only matches dated before or on this date time.
  'destination': "destination_example", // String | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance.
  'destinationDirectory': "destinationDirectory_example", // String | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command.
  'destinationHostname': "destinationHostname_example", // String | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded.
  'destinationPassword': "destinationPassword_example", // String | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'destinationUsername': "destinationUsername_example", // String | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded.
  'ip': "ip_example", // String | String. Case-insensitive substring search of the message “IP Address” if the email program or device that made the connection.
  'reason': "reason_example", // String | String Case-insensitive substring search of the login failure / reason data.
};
apiInstance.getSMTPLoginFailureReportAccount(accountId, opts).then((data) => {
  console.log('API called successfully. Returned data: ' + data);
}, (error) => {
  console.error(error);
});

```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  | 
 **afterDate** | **String**| DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional] 
 **beforeDate** | **String**| DATETIME. Return only matches dated before this date time. | [optional] 
 **firstRow** | **Number**| (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0]
 **fromDate** | **String**| DATETIME. Return only matches dated on or after this date time. | [optional] 
 **matches** | **Number**| (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000]
 **throughDate** | **String**| DATETIME. Return only matches dated before or on this date time. | [optional] 
 **destination** | **String**| For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout -- uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional] 
 **destinationDirectory** | **String**| For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional] 
 **destinationHostname** | **String**| For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationPassword** | **String**| For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **destinationUsername** | **String**| For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional] 
 **ip** | **String**| String. Case-insensitive substring search of the message “IP Address” if the email program or device that made the connection. | [optional] 
 **reason** | **String**| String Case-insensitive substring search of the login failure / reason data. | [optional] 

### Return type

[**InlineResponse20021**](InlineResponse20021.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

